bayespy.inference.vmp.nodes.wishart.WishartMoments
==================================================

.. currentmodule:: bayespy.inference.vmp.nodes.wishart

.. autoclass:: WishartMoments

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~WishartMoments.add_converter
      ~WishartMoments.compute_dims_from_values
      ~WishartMoments.compute_fixed_moments
      ~WishartMoments.get_converter
   
   

   
   
   